// Copyright (c) 2013, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

/**
 * This library defines common dependency injection related classes that could
 * be used across different dependency injection frameworks.
 *
 * The annotations and the [Provider] interface can be used on injectable
 * classes to specify injection points, annotate the injected types, and inject
 * providers. These classes can then be used in any framework that supports
 * the inject library.
 */
library inject;

class InjectAnnotation {
  const InjectAnnotation._();
}

/**
 * A const value intented to be used as a metadata annotation to specify the
 * injection points of a class.
 *
 * Some frameworks will only support a limited set of injection points, like
 * constructor injection.
 *
 * ## Example:
 *
 *     class Injectable {
 *       final Dependency d;
 *
 *       @inject
 *       Injectable(Dependency this.d);
 *     }
 */
const inject = const InjectAnnotation._();

/**
 * A base class for binding annotations. Since injected parameters might have
 * multiple annotations, frameworks need a way of distinguishing a binding
 * annotation from other annotations.
 *
 * In the future, another option might be to annotate the binding annotations
 * themselves.
 */
class BindingAnnotation {
  final value;
  const BindingAnnotation(this.value);
}
